Package: SpatialExperimentIO
Title: Read in Xenium, CosMx, MERSCOPE or STARmapPLUS data as
        SpatialExperiment object
Version: 1.5.0
Authors@R: c(
    person("Yixing E.", "Dong", 
        email = "estelladong729@gmail.com", 
        role = c("aut", "cre"), 
        comment = c(ORCID = "0009-0003-5115-5686")))
URL: https://github.com/estellad/SpatialExperimentIO
BugReports: https://github.com/estellad/SpatialExperimentIO/issues
Description: Read in imaging-based spatial transcriptomics technology data. Current available modules are for Xenium by 10X Genomics, CosMx by Nanostring, MERSCOPE by Vizgen, or STARmapPLUS from Broad Institute. You can choose to read the data in as a SpatialExperiment or a SingleCellExperiment object. 
License: Artistic-2.0
Encoding: UTF-8
VignetteBuilder: knitr
Roxygen: list(markdown = TRUE)
Imports: DropletUtils, SpatialExperiment, SingleCellExperiment,
        methods, data.table, arrow, purrr, S4Vectors
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), BiocStyle
biocViews: DataRepresentation, DataImport, Infrastructure,
        Transcriptomics, SingleCell, Spatial, GeneExpression
RoxygenNote: 7.3.2
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/SpatialExperimentIO
git_branch: devel
git_last_commit: 56f593f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-29
NeedsCompilation: no
Packaged: 2026-04-30 00:34:26 UTC; biocbuild
Author: Yixing E. Dong [aut, cre] (ORCID:
    <https://orcid.org/0009-0003-5115-5686>)
Maintainer: Yixing E. Dong <estelladong729@gmail.com>
Depends: R (>= 4.1.0)
